<?php

namespace Drupal\clinicaltrials\Commands;

use Drupal\clinicaltrials\ClinicalDeleteService;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drush\Commands\DrushCommands;
use Psr\Log\LoggerInterface;

/**
 * Class DeleteCommands.
 *
 * Custom drush command to delete the unwanted clinical trials data.
 *
 * @package Drupal\clinical_trials
 */
class DeleteCommands extends DrushCommands {

  /**
   * Sets a logger instance on the object.
   *
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger instance.
   */
  public function setLogger(LoggerInterface $logger): void {
    $this->logger = $logger;
  }

  /**
   * Entity Manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  private $entityManager;

  /**
   * The service for clinical trials.
   *
   * @var \Drupal\clinicaltrials\ClinicalDeleteService
   */
  protected $clinicalService;

  /**
   * Constructs a new ImportCommands object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityManager
   *   The Entity Type Manager service.
   * @param \Drupal\clinicaltrials\ClinicalDeleteService $clinicalService
   *   Clinical Trial Delete Service.
   */
  public function __construct(EntityTypeManagerInterface $entityManager, ClinicalDeleteService $clinicalService) {
    $this->entityManager = $entityManager;
    $this->clinicalService = $clinicalService;
  }

  /**
   * Drush command which Imports Ctapi data.
   *
   * @command clinical-trial:deleteStudies
   * @aliases ct-delete-studies
   */
  public function doDelete() {
    $this->clinicalService->deleteCtData();
  }

}
