<?php

declare(strict_types=1);

namespace Drupal\Tests\clinicaltrials\Unit;

use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\clinicaltrials\ClinicalUninstallValidator
 * @group book
 */
class ClinicalUninstallValidatorTest extends UnitTestCase {

  /**
   * @var \Drupal\clinicaltrials\ClinicalUninstallValidator|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $clinicalUninstallValidator;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->clinicalUninstallValidator = $this->getMockBuilder('Drupal\clinicaltrials\ClinicalUninstallValidator')
      ->disableOriginalConstructor()
      ->onlyMethods(['hasClinicalNodes'])
      ->getMock();
    $this->clinicalUninstallValidator->setStringTranslation($this->getStringTranslationStub());
  }

  /**
   * @covers ::validate
   */
  public function testValidateNotClinicalTrials() {

    $this->clinicalUninstallValidator->expects($this->never())
      ->method('hasClinicalNodes');

    $module = 'not_clinicaltrials';
    $expected = [];
    $reasons = $this->clinicalUninstallValidator->validate($module);
    $this->assertEquals($expected, $reasons);
  }

  /**
   * @covers ::validate
   */
  public function testValidateEntityQueryWithoutResults() {

    $this->clinicalUninstallValidator->expects($this->once())
      ->method('hasClinicalNodes')
      ->willReturn(FALSE);

    $module = 'clinicaltrials';
    $expected = [];
    $reasons = $this->clinicalUninstallValidator->validate($module);
    $this->assertEquals($expected, $reasons);
  }

  /**
   * @covers ::validate
   */
  public function testValidateEntityQueryWithResults() {

    $this->clinicalUninstallValidator->expects($this->once())
      ->method('hasClinicalNodes')
      ->willReturn(TRUE);

    $module = 'clinicaltrials';
    $expected = ['To uninstall Clinicaltrials module, Please delete all contents which are available in the clinical trials content type.'];
    $reasons = $this->clinicalUninstallValidator->validate($module);
    $this->assertEquals($expected, $reasons);
  }

}
